@@ -1086,7 +1086,7 @@ class llama_beams_state(ctypes.Structure):
 # // Type of pointer to the beam_search_callback function.
 # // void* callback_data is any custom data passed to llama_beam_search, that is subsequently
 # // passed back to beam_search_callback. This avoids having to use global variables in the callback.
-# typedef void (*llama_beam_search_callback_fn_t)(void * callback_data, llama_beams_state);
+# typedef void (*llama_beam_search_callback_fn_t)(void * callback_data, struct llama_beams_state);
 llama_beam_search_callback_fn_t = ctypes.CFUNCTYPE(None, c_void_p, llama_beams_state)
 
 
@@ -1487,6 +1487,15 @@ def llama_log_set(
 _lib.llama_log_set.argtypes = [llama_log_callback, c_void_p]
 _lib.llama_log_set.restype = None
 
+
+# LLAMA_API void llama_dump_timing_info_yaml(FILE * stream, const struct llama_context * ctx);
+def llama_dump_timing_info_yaml(stream: ctypes.c_void_p, ctx: llama_context_p):
+    return _lib.llama_dump_timing_info_yaml(stream, ctx)
+
+_lib.llama_dump_timing_info_yaml.argtypes = [ctypes.c_void_p, llama_context_p]
+_lib.llama_dump_timing_info_yaml.restype = None
+
+
 ###################################################################################################
 
 
